==> nextcloud-21.0.0p0.tgz: nextcloud/apps/weather_status/l10n/fi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Tuntematon osoite",
    "No result." : "Ei tuloksia.",
    "Malformed JSON data." : "Virheellinen JSON-data.",
    "Error" : "Virhe",
    "Weather status" : "Säätiedot",
    "Weather status in your dashboard" : "Säätiedot konsolissasi",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna konsoliin.\n    Käyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\n    Tiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen.",
    "Detect location" : "Tunnista sijainti",
    "Set custom address" : "Syötä osoite",
    "Favorites" : "Suosikit",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Kirkas taivas klo {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Pilvistä klo {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Puolipilvistä klo {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Sumuista klo {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Kevyttä sadetta klo {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Sadetta klo {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Rankkasadetta klo {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Sadekuuroja klo {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Kevyitä sadekuuroja klo {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Rankkoja sadekuuroja klo {time}",
    "More weather for {adr}" : "Lisää säätietoja kohteesta {adr}",
    "Loading weather" : "Ladataan säätietoa",
    "Set location for weather" : "Aseta sijainti säätiedoille",
    "Remove from favorites" : "Poista suosikeista",
    "Add as favorite" : "Lisää suosikiksi",
    "You are not logged in." : "Et ole kirjautuneena sisään.",
    "There was an error getting the weather status information." : "Säätietojen noudossa tapahtui virhe.",
    "No weather information found" : "Säätietoja ei löytynyt",
    "Location not found" : "Sijaintia ei löytynyt",
    "There was an error setting the location address." : "Sijainnin osoitteen asettamisessa tapahtui virhe.",
    "There was an error setting the location." : "Sijainnin asettamisessa tapahtui virhe.",
    "There was an error saving the mode." : "Tilan tallennuksessa tapahtui virhe.",
    "There was an error using personal address." : "Henkilökohtaisen osoitteen käytössä tapahtui virhe.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna konsoliin.\nKäyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\nTiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.4.tgz: nextcloud/apps/weather_status/l10n/fi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Tuntematon osoite",
    "No result." : "Ei tuloksia.",
    "Malformed JSON data." : "Virheellinen JSON-data.",
    "Error" : "Virhe",
    "Weather status" : "Säätiedot",
    "Weather status in your dashboard" : "Säätiedot konsolissasi",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna konsoliin.\n    Käyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\n    Tiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen.",
    "Detect location" : "Tunnista sijainti",
    "Set custom address" : "Syötä osoite",
    "Favorites" : "Suosikit",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Kirkas taivas klo {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Pilvistä klo {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Pilvetöntä klo {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Pilvetöntä {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Puolipilvistä klo {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Sumuista klo {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Kevyttä sadetta klo {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Sadetta klo {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Rankkasadetta klo {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Sadekuuroja klo {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Kevyitä sadekuuroja klo {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Rankkoja sadekuuroja klo {time}",
    "More weather for {adr}" : "Lisää säätietoja kohteesta {adr}",
    "Loading weather" : "Ladataan säätietoa",
    "Set location for weather" : "Aseta sijainti säätiedoille",
    "Remove from favorites" : "Poista suosikeista",
    "Add as favorite" : "Lisää suosikiksi",
    "You are not logged in." : "Et ole kirjautuneena sisään.",
    "There was an error getting the weather status information." : "Säätietojen noudossa tapahtui virhe.",
    "No weather information found" : "Säätietoja ei löytynyt",
    "Location not found" : "Sijaintia ei löytynyt",
    "There was an error setting the location address." : "Sijainnin osoitteen asettamisessa tapahtui virhe.",
    "There was an error setting the location." : "Sijainnin asettamisessa tapahtui virhe.",
    "There was an error saving the mode." : "Tilan tallennuksessa tapahtui virhe.",
    "There was an error using personal address." : "Henkilökohtaisen osoitteen käytössä tapahtui virhe.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Säätiedot integroituna konsoliin.\nKäyttäjän sijainti voidaan joko tunnistaa automaattisesti tai asettaa manuaalisesti. Sääennuste näytetään kuudelle tunnille.\nTiedot voidaan myös integroida muihin paikkoihin, kuten kalenterisovellukseen."
},
"nplurals=2; plural=(n != 1);");
